@@ -3,7 +3,7 @@
 #
 # Onionprobe test/monitor tool.
 #
-# Copyright (C) 2022 Silvio Rhatto <rhatto@torproject.org>
+# Copyright (C) 2022 The Tor Project, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published
@@ -114,12 +114,68 @@ metrics = {
             ['name', 'address', 'reachable']
         ),
 
+    'onion_service_descriptor_revision_counter': Gauge(
+            'onion_service_descriptor_revision_counter',
+            'Register Onion Service descriptor revision counter',
+            ['name', 'address']
+        ),
+
+    'onion_service_descriptor_lifetime_seconds': Gauge(
+            'onion_service_descriptor_lifetime_seconds',
+            'Register Onion Service descriptor lifetime in seconds',
+            ['name', 'address']
+        ),
+
+    'onion_service_descriptor_outer_wrapper_size_bytes': Gauge(
+            'onion_service_descriptor_outer_wrapper_size_bytes',
+            'Register Onion Service outer wrapper descriptor size in bytes (decrypted)',
+            ['name', 'address']
+        ),
+
+    'onion_service_descriptor_second_layer_size_bytes': Gauge(
+            'onion_service_descriptor_second_layer_size_bytes',
+            'Register Onion Service second layer descriptor size in bytes (decrypted)',
+            ['name', 'address']
+        ),
+
+    'onion_service_is_single': Gauge(
+            'onion_service_is_single',
+            "Indicates whether the server is using the single hop Onion Service circuit mode: value is " + \
+                    "1 if this is a single onion service, 0 otherwise",
+            ['name', 'address']
+        ),
+
     'onion_service_introduction_points_number': Gauge(
             'onion_service_introduction_points_number',
             'Register the number of introduction points in the Onion Service descriptor',
             ['name', 'address']
         ),
 
+    'onion_service_pow_enabled': Gauge(
+            'onion_service_pow_enabled',
+            "Whether Proof of Work (PoW) defense is enabled in the Onion Service: value is " + \
+                    "1 when PoW is enabled, 0 otherwise",
+            ['name', 'address']
+        ),
+
+    'onion_service_pow_v1_seed': Gauge(
+            'onion_service_pow_v1_seed',
+            'The Proof of Work (PoW) decoded seed for the v1 scheme',
+            ['name', 'address']
+        ),
+
+    'onion_service_pow_v1_effort': Gauge(
+            'onion_service_pow_v1_effort',
+            'The Proof of Work (PoW) suggested effort for the v1 scheme',
+            ['name', 'address']
+        ),
+
+    'onion_service_pow_v1_expiration_seconds': Gauge(
+            'onion_service_pow_v1_expiration_seconds',
+            'The Proof of Work (PoW) seed expiration time for the v1 scheme',
+            ['name', 'address']
+        ),
+
     'onion_service_match_pattern_matched': Gauge(
             'onion_service_pattern_matched',
             "Register whether a regular expression pattern is matched when " + \
@@ -168,6 +224,12 @@ metrics = {
             ['name', 'address', 'port']
         ),
 
+    'hsdir_latency_seconds': Gauge(
+            'hsdir_latency_seconds',
+            'Register HSDir latency in seconds to fetch a descriptor',
+            ['name', 'id', ]
+        ),
+
     #
     # Probing counters
     #
